/*
 *  npw-dir.h - Directory management for nspluginwrapper
 *
 *  by Martin Stransky <stransky@redhat.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "sysdeps.h"
#include "npw-dir.h"

#include <assert.h>
#include <sys/types.h>
#include <unistd.h>

/*
Expect defined:
#define NPW_PREFIX  (/usr)
#define NPW_LIB32   (lib)
#define NPW_LIB64   (lib64)
#define NPW_DIR     (nspluginwrapper)
*/

char * get_plugin_path(char *p_path, int max_path, const char *p_arch)
{
  char *p_arch_lib = NULL;
  
  if(!strcmp(p_arch, "i386")) {    
    p_arch_lib = NPW_LIB32;
  }
  else if(!strcmp(p_arch, "x86_64")) {
    p_arch_lib = NPW_LIB64;
  } 
  else {
    assert(0);
  }    
  snprintf(p_path,max_path,"%s/%s/%s",NPW_PREFIX,p_arch_lib,NPW_DIR);
  return(p_path); 
}

char * get_plugin(char *p_path, int max_path, const char *p_arch, const char *p_plugin)
{
  char *p_arch_lib = NULL;
  
  if(!strcmp(p_arch, "i386")) {    
    p_arch_lib = NPW_LIB32;
  }
  else if(!strcmp(p_arch, "x86_64")) {
    p_arch_lib = NPW_LIB64;
  } 
  else {
    assert(0);
  }    
  snprintf(p_path,max_path,"%s/%s/%s/%s",NPW_PREFIX,p_arch_lib,NPW_DIR,p_plugin);
  return(p_path);  
}

//#define NPW_DEFAULT_PLUGIN_PATH NPW_LIBDIR "/" HOST_ARCH "/" HOST_OS "/" NPW_WRAPPER
char * get_default_plugin(char *p_path, int max_path)
{
  snprintf(p_path,max_path,"%s/%s/%s",LIBDIR,NPW_DIR,NPW_WRAPPER);
  return(p_path);
}

//#define NPW_OLD_DEFAULT_PLUGIN_PATH NPW_LIBDIR "/" HOST_ARCH "/" NPW_WRAPPER
char * get_old_default_plugin(char *p_path, int max_path)
{
  return(get_default_plugin(p_path, max_path));
}

char * get_viewer_path(char *p_path, int max_path, const char *p_arch)
{
  return(get_plugin_path(p_path, max_path, p_arch));
}

char * get_viewer(char *p_path, int max_path, const char *p_arch, const char *p_viewer)
{
  return(get_plugin(p_path, max_path, p_arch, p_viewer));
}

char * get_connection_path(char *p_path, int max_path, const char *p_plugin, int init_count)
{
  snprintf(p_path, max_path, "%s/%s/%d-%d", NPW_CONNECTION_PATH, p_plugin, getpid(), init_count);
  return(p_path);
}
